@@ -192,7 +192,7 @@ ModuleView::ModuleView(const std::shared_ptr<QQmlEngine> &engine, QWidget *paren
     d->mReset->setEnabled(false);
     d->mHelp->setEnabled(false);
     // Connect up the buttons
-    connect(d->mApply, SIGNAL(clicked()), this, SLOT(moduleSave()));
+    connect(d->mApply, &QPushButton::clicked, this, &ModuleView::saveActiveModule);
     connect(d->mReset, &QAbstractButton::clicked, this, &ModuleView::moduleLoad);
     connect(d->mHelp, &QAbstractButton::clicked, this, &ModuleView::moduleHelp);
     connect(d->mDefault, &QAbstractButton::clicked, this, &ModuleView::moduleDefaults);
@@ -368,7 +368,8 @@ bool ModuleView::resolveChanges(KCModule *kcm)
 
     switch (result) {
     case KMessageDialog::PrimaryAction:
-        return moduleSave(kcm);
+        moduleSave(kcm);
+        return true;
     case KMessageDialog::SecondaryAction:
         kcm->load();
         return true;
@@ -395,21 +396,17 @@ void ModuleView::closeModules()
     d->pageChangeSupressed = false;
 }
 
-bool ModuleView::moduleSave()
+void ModuleView::saveActiveModule()
 {
     KCModule *moduleProxy = d->mPages.value(d->mPageWidget->currentPage());
-    return moduleSave(moduleProxy);
+    Q_ASSERT(moduleProxy);
+    moduleSave(moduleProxy);
 }
 
-bool ModuleView::moduleSave(KCModule *module)
+void ModuleView::moduleSave(KCModule *module)
 {
-    if (!module) {
-        return false;
-    }
-
     module->save();
     Q_EMIT moduleSaved();
-    return true;
 }
 
 void ModuleView::moduleLoad()
@@ -522,9 +519,6 @@ void ModuleView::updateButtons()
         if (activeModule->metaData().value(QStringLiteral("X-DocPath")).isEmpty()) {
             buttons &= ~KCModule::Help;
         }
-
-        disconnect(d->mApply, SIGNAL(clicked()), this, SLOT(moduleSave()));
-        connect(d->mApply, SIGNAL(clicked()), this, SLOT(moduleSave()));
     } else {
         d->authAction = KAuth::Action();
     }
